@@ -279,7 +279,7 @@ class HarvestedRecord(object):
     def stat(self, filepath, version=None):
         if not version:
             version = self.currentversion
-        return self.po.stat(filepath)
+        return self.po.stat(os.path.join("__%s" % version, filepath))
 
     def set_version_cursor(self, version):
         if version in self.manifest['versions']:
